@@ -66,14 +66,17 @@ public class ExportToHTMLPlugin : NotePlugin
 		ExportToHTMLDialog dialog = new ExportToHTMLDialog (Note.Title + ".html");
 		int response = dialog.Run();
 		string output_path = dialog.Filename;
-		dialog.Destroy ();
 
-		if (response != (int) Gtk.ResponseType.Ok) 
+		if (response != (int) Gtk.ResponseType.Ok) {
+			dialog.Destroy ();
 			return;
+		}
 
 		Logger.Log ("Exporting Note '{0}' to '{1}'...", Note.Title, output_path);
 
 		StreamWriter writer = null;
+		string error_message = null;
+
 		try {
 			try {
 				// FIXME: Warn about file existing.  Allow overwrite.
@@ -83,15 +86,72 @@ public class ExportToHTMLPlugin : NotePlugin
 
 			writer = new StreamWriter (output_path);
 			WriteHTMLForNote (writer, Note, dialog.ExportLinked);
+			
+			// Save the dialog preferences now that the note has
+			// successfully been exported
+			dialog.SavePreferences ();
+			dialog.Destroy ();
+			dialog = null;
+			
+			try {
+				Uri output_uri = new Uri (output_path);
+				Gnome.Url.Show (output_uri.AbsoluteUri);
+			} catch (Exception ex) {
+				Logger.Log ("Could not open exported note in a web browser: {0}", 
+					    ex);
 
-			Uri output_uri = new Uri (output_path);
-			Gnome.Url.Show (output_uri.AbsoluteUri);
+				string detail = String.Format (
+					Catalog.GetString ("Your note was exported to \"{0}\"."),
+					output_path);
+
+				// Let the user know the note was saved successfully
+				// even though showing the note in a web browser failed.
+				HIGMessageDialog msg_dialog =
+					new HIGMessageDialog (
+						Window,
+						Gtk.DialogFlags.DestroyWithParent,
+						Gtk.MessageType.Info,
+						Gtk.ButtonsType.Ok,
+						Catalog.GetString ("Note exported successfully"),
+						detail);
+				msg_dialog.Run ();
+				msg_dialog.Destroy ();
+			}
+		} catch (UnauthorizedAccessException uae) {
+			error_message = Catalog.GetString ("Access denied.");
+		} catch (DirectoryNotFoundException dnfe) {
+			error_message = Catalog.GetString ("Folder does not exist.");
 		} catch (Exception e) {
 			Logger.Log ("Could not export: {0}", e);
+			
+			error_message = e.Message;
 		} finally {
 			if (writer != null) 
 				writer.Close ();
 		}
+
+		if (error_message != null)
+		{
+			Logger.Log ("Could not export: {0}", error_message);
+
+			string msg = String.Format (
+				Catalog.GetString ("Could not save the file \"{0}\""), 
+				output_path);
+
+			HIGMessageDialog msg_dialog = 
+				new HIGMessageDialog (
+					dialog,
+					Gtk.DialogFlags.DestroyWithParent,
+					Gtk.MessageType.Error,
+					Gtk.ButtonsType.Ok,
+					msg,
+					error_message);
+			msg_dialog.Run ();
+			msg_dialog.Destroy ();
+		}
+
+		if (dialog != null)
+			dialog.Destroy ();
 	}
 
 	public void WriteHTMLForNote (TextWriter writer, 
@@ -193,18 +253,24 @@ class NoteNameResolver : XmlResolver
 	}
 }
 
-class ExportToHTMLDialog : Gtk.FileSelection
+class ExportToHTMLDialog : Gtk.FileChooserDialog
 {
 	Gtk.CheckButton export_linked;
 
 	public ExportToHTMLDialog (string default_file) : 
-		base (Catalog.GetString ("Destination for HTML Export")) 
+		base (Catalog.GetString ("Destination for HTML Export"),
+			  null, Gtk.FileChooserAction.Save, new object[] {})
 	{
-		Response += OnResponseCb;
-
-		HideFileopButtons ();
+		AddButton (Gtk.Stock.Cancel, Gtk.ResponseType.Cancel);
+		AddButton (Gtk.Stock.Save, Gtk.ResponseType.Ok);
+		
+		DefaultResponse = Gtk.ResponseType.Ok;
+		
 		export_linked = new Gtk.CheckButton (Catalog.GetString ("Export linked notes"));
-		VBox.Add (export_linked);
+		ExtraWidget = export_linked;
+		
+		DoOverwriteConfirmation = true;
+		LocalOnly = true;
 
 		ShowAll ();
 		LoadPreferences (default_file);
@@ -215,30 +281,23 @@ class ExportToHTMLDialog : Gtk.FileSelection
 		get { return export_linked.Active; }
 		set { export_linked.Active = value; }
 	}
-
-	protected void OnResponseCb (object sender, Gtk.ResponseArgs args) 
-	{
-		if (args.ResponseId == Gtk.ResponseType.Ok) 
-			SavePreferences ();
-	}
-
-	protected void LoadPreferences (string default_file) 
-	{
-		string last_dir = (string) Preferences.Get (Preferences.EXPORTHTML_LAST_DIRECTORY);
-		if (last_dir == "")
-			last_dir = Environment.GetEnvironmentVariable ("HOME");
-		last_dir = System.IO.Path.Combine (last_dir, default_file);
-		Filename = last_dir;
-
-		ExportLinked = (bool) Preferences.Get (Preferences.EXPORTHTML_EXPORT_LINKED);
-	}
-
-	protected void SavePreferences () 
+	
+	public void SavePreferences () 
 	{
 		string dir = System.IO.Path.GetDirectoryName (Filename);
 		Preferences.Set (Preferences.EXPORTHTML_LAST_DIRECTORY, dir);
 
 		Preferences.Set (Preferences.EXPORTHTML_EXPORT_LINKED, ExportLinked);
 	}
-}
+	
+	protected void LoadPreferences (string default_file) 
+	{
+		string last_dir = (string) Preferences.Get (Preferences.EXPORTHTML_LAST_DIRECTORY);
+		if (last_dir == "")
+			last_dir = Environment.GetEnvironmentVariable ("HOME");
+		SetCurrentFolder (last_dir);
+		CurrentName = default_file;
 
+		ExportLinked = (bool) Preferences.Get (Preferences.EXPORTHTML_EXPORT_LINKED);
+	}
+}
